import NFTSales from 0xNFTSales

pub struct SalesData {
    pub let uuid: UInt64
    pub let id: UInt64 
    pub let salesOpenOverride: UInt8
    pub let maxSHRD: UFix64 
    pub let mintedSHRD: UFix64 
    pub let shrdPerGrade: {String:UFix64}
    pub let cardsPerPack: UInt64
    pub let price: UFix64 
    pub let publicKey: String 
    pub let startTime: UFix64 
    pub let endTime: UFix64
    pub let maxPerWallet: UInt64 
    pub let cardCount: UInt64
    pub let cardCountBySpecifiedWallet: UInt64
    init(
            uuid: UInt64,
            id: UInt64,
            salesOpenOverride: UInt8,
            maxSHRD: UFix64,
            mintedSHRD: UFix64, 
            shrdPerGrade: {String:UFix64},
            cardsPerPack: UInt64,
            price: UFix64, 
            publicKey: String, 
            startTime: UFix64, 
            endTime: UFix64,
            maxPerWallet: UInt64, 
            cardCount: UInt64,
            cardCountBySpecifiedWallet: UInt64
        ) {
        self.uuid = uuid
        self.id = id
        self.salesOpenOverride = salesOpenOverride
        self.maxSHRD = maxSHRD
        self.mintedSHRD = mintedSHRD
        self.shrdPerGrade = shrdPerGrade
        self.cardsPerPack = cardsPerPack
        self.price = price
        self.publicKey = publicKey
        self.startTime = startTime
        self.endTime = endTime
        self.maxPerWallet = maxPerWallet
        self.cardCount = cardCount
        self.cardCountBySpecifiedWallet = cardCountBySpecifiedWallet
    }
}

pub fun main(salesCollectionAddress: Address, salesIDs: [UInt64]): [SalesData] {
    let res:[SalesData] = []
    for index, salesID in salesIDs {
        let acct = getAccount(salesCollectionAddress)
        let cap = acct.getCapability<&NFTSales.SalesCollection{NFTSales.SalesCollectionPublic}>(NFTSales.SalesCollectionPublicPath)!
        let capRef = cap.borrow()!
        let salesRef = capRef.borrowSales(salesID: salesID)
        
        let salesData = SalesData(
            uuid: salesRef.uuid,
            id: salesRef.id,
            salesOpenOverride: salesRef.salesOpenOverride,
            maxSHRD: salesRef.maxSHRD,
            mintedSHRD: salesRef.mintedSHRD, 
            shrdPerGrade: salesRef.getSHRDPerGrade(),
            cardsPerPack: salesRef.cardsPerPack,
            price: salesRef.price, 
            publicKey: salesRef.publicKey, 
            startTime: salesRef.startTime, 
            endTime: salesRef.endTime,
            maxPerWallet: salesRef.maxPerWallet, 
            cardCount: salesRef.cardCount,
            cardCountBySpecifiedWallet: UInt64(0) // placeholder value
        )
        res.append(salesData)
    }
    return res
}